@@ -1,6 +1,6 @@
-/* Copyright © 2008-2015 Jakub Wilk <jwilk@jwilk.net>
+/* Copyright © 2008-2017 Jakub Wilk <jwilk@jwilk.net>
  *
- * This file is part of pdfdjvu.
+ * This file is part of pdf2djvu.
  *
  * pdf2djvu is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 as
@@ -14,6 +14,7 @@
 
 #include "image-filter.hh"
 
+#include <cstddef>
 #include <bitset>
 #include <map>
 #include <ostream>
@@ -92,9 +93,11 @@ void MaskQuantizer::operator()(pdf::Renderer *out_fg, pdf::Renderer *out_bg, int
       }
       else
         r4 << 0;
-      p_fg++, p_bg++;
+      p_fg++;
+      p_bg++;
     }
-    p_fg.next_row(), p_bg.next_row();
+    p_fg.next_row();
+    p_bg.next_row();
   }
 
 }
@@ -118,7 +121,7 @@ void WebSafeQuantizer::operator()(pdf::Renderer *out_fg, pdf::Renderer *out_bg,
     background_color[i] = p_bg[i];
   for (int y = 0; y < height; y++)
   {
-    int new_color, color = 0xfff;
+    int new_color, color = 0xFFF;
     int length = 0;
     for (int x = 0; x < width; x++)
     {
@@ -138,20 +141,22 @@ void WebSafeQuantizer::operator()(pdf::Renderer *out_fg, pdf::Renderer *out_bg,
         new_color = ((p_fg[2] + 1) / 43) + 6 * (((p_fg[1] + 1) / 43) + 6 * ((p_fg[0] + 1) / 43));
       }
       else
-        new_color = 0xfff;
+        new_color = 0xFFF;
       if (color == new_color)
         length++;
       else
       {
         if (length > 0)
-          write_uint32(stream, ((uint32_t)color << 20) + length);
+          write_uint32(stream, (static_cast<uint32_t>(color) << 20) + length);
         color = new_color;
         length = 1;
       }
-      p_fg++, p_bg++;
+      p_fg++;
+      p_bg++;
     }
-    p_fg.next_row(), p_bg.next_row();
-    write_uint32(stream, ((uint32_t)color << 20) + length);
+    p_fg.next_row();
+    p_bg.next_row();
+    write_uint32(stream, (static_cast<uint32_t>(color) << 20) + length);
   }
 }
 
@@ -180,7 +185,7 @@ public:
   int operator [](int i) const
   {
     return
-      (((this->value >> (6 * i)) << 2) & 0xff) |
+      (((this->value >> (6 * i)) << 2) & 0xFF) |
       ((this->value >> (6 * i + 4)) & 3);
   }
 
@@ -296,9 +301,11 @@ void DefaultQuantizer::operator()(pdf::Renderer *out_fg, pdf::Renderer *out_bg,
         run = Run(new_color);
         run++;
       }
-      p_fg++, p_bg++;
+      p_fg++;
+      p_bg++;
     }
-    p_fg.next_row(), p_bg.next_row();
+    p_fg.next_row();
+    p_bg.next_row();
     if (run.get_length() > 0)
       runs[y].push_back(run);
   }
@@ -329,7 +336,7 @@ void DefaultQuantizer::operator()(pdf::Renderer *out_fg, pdf::Renderer *out_bg,
   /* Output the palette: */
   if (color_counter == 0)
   {
-    stream << 1 << std::endl << "\xff\xff\xff";
+    stream << 1 << std::endl << "\xFF\xFF\xFF";
   }
   else
   {
@@ -349,7 +356,7 @@ void DefaultQuantizer::operator()(pdf::Renderer *out_fg, pdf::Renderer *out_bg,
   /* Map colors into color indices: */
   std::map<int, uint32_t> color_map;
   uint32_t last_color_index = 0;
-  color_map[-1] = 0xfff;
+  color_map[-1] = 0xFFF;
   if (divisor == 4)
     for (size_t color = 0; color < original_colors.size(); color++)
     {
@@ -376,10 +383,10 @@ void DefaultQuantizer::operator()(pdf::Renderer *out_fg, pdf::Renderer *out_bg,
   for (int y = 0; y < height; y++)
   {
     const std::vector<Run> line_runs = runs[y];
-    for (std::vector<Run>::const_iterator run = line_runs.begin(); run != line_runs.end(); run++)
+    for (const Run &run : line_runs)
     {
-      uint32_t color_index = color_map[run->get_color()];
-      write_uint32(stream, ((uint32_t)color_index << 20) + run->get_length());
+      uint32_t color_index = color_map[run.get_color()];
+      write_uint32(stream, (static_cast<uint32_t>(color_index) << 20) + run.get_length());
     }
   }
 }
@@ -389,7 +396,7 @@ static void dummy_quantizer(int width, int height, int *background_color, std::o
   rle::R4 r4(stream, width, height);
   for (int y = 0; y < height; y++)
     r4.output_run(width);
-  background_color[0] = background_color[1] = background_color[2] = 0xff;
+  background_color[0] = background_color[1] = background_color[2] = 0xFF;
 }
 
 void DummyQuantizer::operator()(pdf::Renderer *out_fg, pdf::Renderer *out_bg, int width, int height,
@@ -403,7 +410,7 @@ void DummyQuantizer::operator()(pdf::Renderer *out_fg, pdf::Renderer *out_bg, in
 class GraphicsMagickInitializer
 {
 public:
-  GraphicsMagickInitializer(void)
+  GraphicsMagickInitializer()
   {
     Magick::InitializeMagick("");
   }
@@ -473,9 +480,13 @@ void GraphicsMagickQuantizer::operator()(pdf::Renderer *out_fg, pdf::Renderer *o
       }
       else
         *ipixel = Magick::Color(0, 0, 0, TransparentOpacity);
-      p_fg++, p_bg++, ipixel++;
+      p_fg++;
+      p_bg++;
+      ipixel++;
     }
-    p_fg.next_row(), p_bg.next_row(), image.syncPixels();
+    p_fg.next_row();
+    p_bg.next_row();
+    image.syncPixels();
   }
   image.quantizeColorSpace(Magick::TransparentColorspace);
   image.quantizeColors(this->config.fg_colors);
@@ -498,7 +509,7 @@ void GraphicsMagickQuantizer::operator()(pdf::Renderer *out_fg, pdf::Renderer *o
   }
   for (int y = 0; y < height; y++)
   {
-    int new_color, color = 0xfff;
+    int new_color, color = 0xFFF;
     Magick::PixelPacket *ipixel = image.getPixels(0, y, width, 1);
     Magick::IndexPacket *ppixel = image.getIndexes();
     int length = 0;
@@ -507,19 +518,20 @@ void GraphicsMagickQuantizer::operator()(pdf::Renderer *out_fg, pdf::Renderer *o
       if (ipixel->opacity != TransparentOpacity)
         new_color = *ppixel;
       else
-        new_color = 0xfff;
+        new_color = 0xFFF;
       if (color == new_color)
         length++;
       else
       {
         if (length > 0)
-          write_uint32(stream, ((uint32_t)color << 20) + length);
+          write_uint32(stream, (static_cast<uint32_t>(color) << 20) + length);
         color = new_color;
         length = 1;
       }
-      ipixel++, ppixel++;
+      ipixel++;
+      ppixel++;
     }
-    write_uint32(stream, ((uint32_t)color << 20) + length);
+    write_uint32(stream, (static_cast<uint32_t>(color) << 20) + length);
   }
 }
 
