@@ -1,4 +1,4 @@
-/* Copyright © 2007-2016 Jakub Wilk <jwilk@jwilk.net>
+/* Copyright © 2007-2017 Jakub Wilk <jwilk@jwilk.net>
  * Copyright © 2009 Mateusz Turcza
  *
  * This file is part of pdf2djvu.
@@ -48,28 +48,6 @@
  * ======================
  */
 
-#if POPPLER_VERSION < 1900
-static void poppler_error_handler(pdf::Offset pos, char *message, va_list args)
-{
-  std::string format;
-  std::string expanded_message = string_vprintf(message, args);
-  const char *c_message = expanded_message.c_str();
-  const char *category = _("PDF error");
-  if (pos >= 0)
-  {
-    error_log <<
-      /* L10N: "<error-category> (<position>): <error-message>" */
-      string_printf(_("%s (%jd): %s"), category, static_cast<intmax_t>(pos), c_message);
-  }
-  else
-  {
-    error_log <<
-      /* L10N: "<error-category>: <error-message>" */
-      string_printf(_("%s: %s"), category, c_message);
-  }
-  error_log << std::endl;
-}
-#else
 static void poppler_error_handler(void *data, ErrorCategory category, pdf::Offset pos, char *message)
 {
   std::string format;
@@ -115,22 +93,11 @@ static void poppler_error_handler(void *data, ErrorCategory category, pdf::Offse
   }
   error_log << std::endl;
 }
-#endif
 
 pdf::Environment::Environment()
 {
-#if WIN32
-  /* Change the current working directory to be able to read poppler data.
-   * This is not required (and potentially harmful) for Unix installations.
-   */
-  Cwd cwd(program_dir);
-#endif
   globalParams = new GlobalParams();
-#if POPPLER_VERSION < 1900
-  setErrorFunction(poppler_error_handler);
-#else
   setErrorCallback(poppler_error_handler, nullptr);
-#endif
 }
 
 void pdf::Environment::set_antialias(bool value)
@@ -163,7 +130,7 @@ static std::string html_color(const double rgb[])
   for (int i = 0; i < 3; i++)
     stream
       << std::setw(2) << std::setfill('0') << std::hex
-      << static_cast<int>(rgb[i] * 0xff);
+      << static_cast<int>(rgb[i] * 0xFF);
   return stream.str();
 }
 
@@ -402,7 +369,7 @@ pdf::Metadata::Metadata(pdf::Document &document)
   date_fields.push_back(std::make_pair("ModDate", &this->mod_date));
 
   pdf::OwnedObject info;
-  document.getDocInfo(&info);
+  document.get_doc_info(info);
   if (!info.isDict())
     return;
   pdf::Dict *info_dict = info.getDict();
@@ -485,8 +452,8 @@ pdf::Renderer::Renderer(pdf::splash::Color &paper_color, bool monochrome)
 : pdf::splash::OutputDevice(monochrome ? splashModeMono1 : splashModeRGB8, 4, false, paper_color)
 {
 #if POPPLER_VERSION >= 3100
-      this->setFontAntialias(pdf::Environment::antialias);
-      this->setVectorAntialias(pdf::Environment::antialias);
+  this->setFontAntialias(pdf::Environment::antialias);
+  this->setVectorAntialias(pdf::Environment::antialias);
 #endif
 }
 
@@ -535,7 +502,7 @@ void pdf::Renderer::convert_path(pdf::gfx::State *state, splash::Path &splash_pa
     {
       double x1, y1, x2, y2, x3, y3;
       state->transform(subpath->getX(0), subpath->getY(0), &x1, &y1);
-      splash_path.moveTo((splash::Coord)x1, (splash::Coord)y1);
+      splash_path.moveTo(static_cast<splash::Coord>(x1), static_cast<splash::Coord>(y1));
       int j = 1;
       int n_points = subpath->getNumPoints();
       while (j < n_points)
@@ -546,16 +513,16 @@ void pdf::Renderer::convert_path(pdf::gfx::State *state, splash::Path &splash_pa
           state->transform(subpath->getX(j + 1), subpath->getY(j + 1), &x2, &y2);
           state->transform(subpath->getX(j + 2), subpath->getY(j + 2), &x3, &y3);
           splash_path.curveTo(
-            (splash::Coord)x1, (splash::Coord)y1,
-            (splash::Coord)x2, (splash::Coord)y2,
-            (splash::Coord)x3, (splash::Coord)y3
+            static_cast<splash::Coord>(x1), static_cast<splash::Coord>(y1),
+            static_cast<splash::Coord>(x2), static_cast<splash::Coord>(y2),
+            static_cast<splash::Coord>(x3), static_cast<splash::Coord>(y3)
           );
           j += 3;
         }
         else
         {
           state->transform(subpath->getX(j), subpath->getY(j), &x1, &y1);
-          splash_path.lineTo((splash::Coord)x1, (splash::Coord)y1);
+          splash_path.lineTo(static_cast<splash::Coord>(x1), static_cast<splash::Coord>(y1));
           j++;
         }
       }
@@ -591,17 +558,27 @@ double pdf::get_path_area(splash::Path &path)
 
 pdf::Object *pdf::dict_lookup(pdf::Object &dict, const char *key, pdf::Object *object)
 {
+#if POPPLER_VERSION < 5800
   return dict.dictLookup(const_cast<char*>(key), object);
+#else
+  *object = dict.dictLookup(const_cast<char*>(key));
+  return object;
+#endif
 }
 
 pdf::Object *pdf::dict_lookup(pdf::Object *dict, const char *key, pdf::Object *object)
 {
-  return dict->dictLookup(const_cast<char*>(key), object);
+  return pdf::dict_lookup(*dict, key, object);
 }
 
 pdf::Object *pdf::dict_lookup(pdf::Dict *dict, const char *key, pdf::Object *object)
 {
+#if POPPLER_VERSION < 5800
   return dict->lookup(const_cast<char*>(key), object);
+#else
+  *object = dict->lookup(const_cast<char*>(key));
+  return object;
+#endif
 }
 
 
@@ -619,7 +596,7 @@ namespace pdf
       for (int y = 0; y < pixmap.height; y++)
       {
         for (size_t x = 0; x < pixmap.byte_width; x++)
-          stream.put(static_cast<char>(row_ptr[x] ^ 0xff));
+          stream.put(static_cast<char>(row_ptr[x] ^ 0xFF));
         row_ptr += pixmap.row_size;
       }
     }
