@@ -55,7 +55,7 @@
 #include "version.hh"
 #include "xmp.hh"
 
-Config config;
+static Config config;
 
 static inline DebugStream &debug(int n)
 {
@@ -273,7 +273,7 @@ public:
     return config.page_id_template->format(bindings);
   }
 
-  virtual ~ComponentList() throw ()
+  virtual ~ComponentList()
   {
     this->clean_files();
   }
@@ -292,7 +292,10 @@ protected:
   void add_text_comment(int ox, int oy, int dx, int dy, int x, int y, int w, int h, const Unicode *unistr, int len)
   {
     while (len > 0 && *unistr == ' ')
-      unistr++, len--;
+    {
+      unistr++;
+      len--;
+    }
     if (len == 0)
       return;
     *(this->text_comments)
@@ -655,7 +658,7 @@ public:
 
 static const int pdf_outline_max_depth = 0x100;
 
-void pdf_outline_to_djvu_outline(pdf::Object *node, pdf::Catalog *catalog,
+static void pdf_outline_to_djvu_outline(pdf::Object *node, pdf::Catalog *catalog,
   djvu::OutlineBase &djvu_outline, const ComponentList &page_files,
   int depth)
 {
@@ -697,7 +700,7 @@ void pdf_outline_to_djvu_outline(pdf::Object *node, pdf::Catalog *catalog,
             catalog
           );
         }
-        catch (const NoLinkDestination &ex)
+        catch (const NoLinkDestination &)
         {
           throw NoPageForBookmark();
         }
@@ -716,10 +719,13 @@ void pdf_outline_to_djvu_outline(pdf::Object *node, pdf::Catalog *catalog,
     }
 
     pdf::dict_lookup(current, "Next", &next);
+#if POPPLER_VERSION < 5800
     current.free();
     current = next;
+#else
+    current = std::move(next);
+#endif
   }
-  current.free();
 }
 
 static void pdf_outline_to_djvu_outline(pdf::Document &doc, djvu::Outline &djvu_outline,
@@ -785,7 +791,7 @@ public:
     shared_ant_file->close();
   }
 
-  virtual ~TemporaryComponentList() throw ()
+  virtual ~TemporaryComponentList()
   {
     this->clean_files();
   }
@@ -858,7 +864,7 @@ public:
   }
   virtual void set_outline(const djvu::Outline &outline) = 0;
   virtual void set_metadata(File &metadata_sed_file) = 0;
-  virtual ~DjVm() throw () { /* just to silence compilers */ }
+  virtual ~DjVm() { /* just to silence compilers */ }
 };
 
 void DjVm::remember(const Component &component)
@@ -886,7 +892,7 @@ public:
     output_file(output_file),
     converter("djvmcvt")
   { }
-  ~BundledDjVm() throw ()
+  ~BundledDjVm()
   { }
   virtual void add(const Component &component);
   virtual void set_outline(const djvu::Outline &outline);
@@ -906,7 +912,7 @@ protected:
   public:
     UnexpectedDjvuSedOutput()
     : std::runtime_error(_("Unexpected output from djvused"))
-    { };
+    { }
   };
   void create_bare(const std::vector<Component> &components);
   void create(const std::vector<Component> &components, bool bare=false);
@@ -916,7 +922,7 @@ public:
     needs_shared_ant(false)
   { }
 
-  virtual ~IndirectDjVm() throw ()
+  virtual ~IndirectDjVm()
   { }
 
   virtual void add(const Component &component)
@@ -1055,7 +1061,7 @@ void IndirectDjVm::create(const std::vector<Component> &components, bool bare)
   this->index_file.write("AT&TFORM\0\0\0\0DJVMDIRM\0\0\0\0\1", 25);
   bool shared_ant = !bare && this->needs_shared_ant;
   for (int i = 1; i >= 0; i--)
-    index_file << static_cast<char>(((size + shared_ant) >> (8 * i)) & 0xff);
+    index_file << static_cast<char>(((size + shared_ant) >> (8 * i)) & 0xFF);
   {
     TemporaryFile bzz_file;
     for (size_t i = 0; i < size + shared_ant; i++)
@@ -1082,7 +1088,7 @@ void IndirectDjVm::create(const std::vector<Component> &components, bool bare)
   File::streamoff dirm_off = this->index_file.size();
   this->index_file.seekp(20, std::ios::beg);
   for (int i = 3; i >= 0; i--)
-    this->index_file << static_cast<char>(((dirm_off - 24) >> (8 * i)) & 0xff);
+    this->index_file << static_cast<char>(((dirm_off - 24) >> (8 * i)) & 0xFF);
   dirm_off += dirm_off & 1;
   if (!bare && this->outline_stream.get())
   {
@@ -1097,12 +1103,12 @@ void IndirectDjVm::create(const std::vector<Component> &components, bool bare)
     File::streamoff outline_off = index_file.size();
     this->index_file.seekp(dirm_off + 4, std::ios::beg);
     for (int i = 3; i >= 0; i--)
-      this->index_file << static_cast<char>(((outline_off - dirm_off - 8) >> (8 * i)) & 0xff);
+      this->index_file << static_cast<char>(((outline_off - dirm_off - 8) >> (8 * i)) & 0xFF);
   }
   File::streamoff off = this->index_file.size();
   this->index_file.seekp(8, std::ios::beg);
   for (int i = 3; i >= 0; i--)
-    this->index_file << static_cast<char>(((off - 12) >> (8 * i)) & 0xff);
+    this->index_file << static_cast<char>(((off - 12) >> (8 * i)) & 0xFF);
   this->index_file.close();
 }
 
@@ -1205,12 +1211,12 @@ static int xmain(int argc, char * const argv[])
   }
   catch (const Config::NeedVersion &)
   {
-    error_log << get_multiline_version();
+    std::cout << get_multiline_version();
     exit(0);
   }
   catch (const Config::NeedHelp &ex)
   {
-    config.usage(ex);
+    config.usage();
     exit(0);
   }
   catch (const Config::Error &ex)
@@ -1235,7 +1241,7 @@ static int xmain(int argc, char * const argv[])
   intmax_t pdf_byte_size = document_map.get_byte_size();
 
   pdf::splash::Color paper_color;
-  pdf::set_color(paper_color, 0xff, 0xff, 0xff);
+  pdf::set_color(paper_color, 0xFF, 0xFF, 0xFF);
 
   intmax_t n_pixels = 0;
   intmax_t djvu_pages_size = 0;
@@ -1482,7 +1488,7 @@ static int xmain(int argc, char * const argv[])
     else
     {
       /* Background is solid. */
-      nonwhite_background_color = (background_color[0] & background_color[1] & background_color[2] & 0xff) != 0xff;
+      nonwhite_background_color = (background_color[0] & background_color[1] & background_color[2] & 0xFF) != 0xFF;
       if (nonwhite_background_color)
       { /* Create a dummy background, just to assure existence of FGbz chunks.
          * The background chunk will be replaced later: */
@@ -1492,7 +1498,7 @@ static int xmain(int argc, char * const argv[])
         sep_file << "P6 " << sub_width << " " << sub_height << " 255" << std::endl;
         for (int x = 0; x < sub_width; x++)
         for (int y = 0; y < sub_height; y++)
-          sep_file.write("\xff\xff\xff", 3);
+          sep_file.write("\xFF\xFF\xFF", 3);
       }
     }
     if (config.text)
@@ -1706,7 +1712,7 @@ static int xmain(int argc, char * const argv[])
         ExistingFile shared_ant(*output_dir, djvu::shared_ant_file_name);
         djvu_size += shared_ant.size();
       }
-      catch (const std::ios_base::failure &ex)
+      catch (const std::ios_base::failure &)
       {
         /* Let's assume that there are no shared annotations. */
       }
