@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2009-2015 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2009-2017 Jakub Wilk <jwilk@jwilk.net>
 #
 # This file is part of pdf2djvu.
 #
@@ -15,21 +15,22 @@
 
 from tools import (
     case,
-    re,
 )
 
+import re
+
 class test(case):
-    # Bug: https://bitbucket.org/jwilk/pdf2djvu/issue/20
-    # + fixed in 0.5.4 [c06a41afdc46]
+    # Bug: https://github.com/jwilk/pdf2djvu/issues/20
+    # + fixed in 0.5.4 [46b70e11778f984c2db302a1c8a18bc0996a387c]
 
     def test_no_crop(self):
         self.pdf2djvu().assert_()
         r = self.print_text()
-        r.assert_(stdout=re('^Lorem ipsum *\n'))
+        r.assert_(stdout=re.compile('^Lorem ipsum *\n'))
 
     def test_crop(self):
         self.pdf2djvu('--crop-text').assert_()
         r = self.print_text()
-        r.assert_(stdout=re('^Lorem *\n'))
+        r.assert_(stdout=re.compile('^Lorem *\n'))
 
 # vim:ts=4 sts=4 sw=4 et
