@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2009-2015 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2009-2017 Jakub Wilk <jwilk@jwilk.net>
 #
 # This file is part of pdf2djvu.
 #
@@ -16,24 +16,25 @@
 from tools import (
     assert_not_equal,
     case,
-    re,
 )
 
-class test(case):
-    # Bug: https://bitbucket.org/jwilk/pdf2djvu/issue/23
-    # + fixed in 0.5.5 [ede3c622526a]
+import re
 
-    # Bug: https://bitbucket.org/jwilk/pdf2djvu/issue/73
-    # + fixed in 0.8 [011677e4ea3e]
+class test(case):
+    # Bug: https://github.com/jwilk/pdf2djvu/issues/23
+    # + fixed in 0.5.5 [ad11da594a254f203f603fd4105fb05c8b508c64]
+
+    # Bug: https://github.com/jwilk/pdf2djvu/issues/73
+    # + fixed in 0.8 [5d5fa0e235497aa7e82ea2ba5fcfd3351ae53562]
 
     def test_bundled(self):
         r = self.pdf2djvu('--pages=1,1')
-        r.assert_(stderr=re('^Duplicate page:', re.M), rc=None)
+        r.assert_(stderr=re.compile('^Duplicate page:', re.M), rc=None)
         assert_not_equal(r.rc, 0)
 
     def test_indirect(self):
         r = self.pdf2djvu_indirect('--pages=1,1')
-        r.assert_(stderr=re('^Duplicate page:', re.M), rc=None)
+        r.assert_(stderr=re.compile('^Duplicate page:', re.M), rc=None)
         assert_not_equal(r.rc, 0)
 
 # vim:ts=4 sts=4 sw=4 et
