@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2010-2015 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2010-2017 Jakub Wilk <jwilk@jwilk.net>
 #
 # This file is part of pdf2djvu.
 #
@@ -13,19 +13,20 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 # General Public License for more details.
 
+import re
+
 from tools import (
     assert_equal,
     assert_in,
     case,
     count_ppm_colors,
-    re,
 )
 
 class test(case):
 
     def test(self):
-        # Bug: https://bitbucket.org/jwilk/pdf2djvu/issue/47
-        # + fixed in 0.7.2 [3d0f55ae5a65]
+        # Bug: https://github.com/jwilk/pdf2djvu/issues/47
+        # + fixed in 0.7.2 [a10cfc8ac94e8f3b7e01e089056bf6a371d1a68d]
         def t(i, n):
             self.require_feature('GraphicsMagick')
             self.pdf2djvu(
@@ -53,7 +54,7 @@ class test(case):
             self.require_feature('GraphicsMagick')
             r = self.pdf2djvu('--fg-colors={0}'.format(i))
             r.assert_(
-                stderr=re('^The specified number of foreground colors is outside the allowed range: 1 .. 4080\n'),
+                stderr=re.compile('^The specified number of foreground colors is outside the allowed range: 1 .. 4080\n'),
                 rc=1,
             )
         t('-1')
@@ -65,7 +66,7 @@ class test(case):
             self.require_feature('GraphicsMagick')
             r = self.pdf2djvu('--fg-colors={0}'.format(i))
             r.assert_(
-                stderr=re('^"{0}" is not a valid number\n'.format(i)),
+                stderr=re.compile('^"{0}" is not a valid number\n'.format(i)),
                 rc=1,
             )
         t('')
