@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2010-2015 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2010-2017 Jakub Wilk <jwilk@jwilk.net>
 #
 # This file is part of pdf2djvu.
 #
@@ -13,18 +13,19 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 # General Public License for more details.
 
+import re
+
 from tools import (
     case,
-    re,
 )
 
 class test(case):
-    # Bug: https://bitbucket.org/jwilk/pdf2djvu/issue/50
-    # + fixed in 0.7.4 [86ae2eb190bd]
+    # Bug: https://github.com/jwilk/pdf2djvu/issues/50
+    # + fixed in 0.7.4 [1c373918e0152d452c24936818591d32df0ff7fc]
 
     def test(self):
         self.pdf2djvu('--pages=2').assert_()
         r = self.print_text()
-        r.assert_(stdout=re('^ipsum *\n'))
+        r.assert_(stdout=re.compile('^ipsum *\n'))
 
 # vim:ts=4 sts=4 sw=4 et
