@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2015 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2015-2018 Jakub Wilk <jwilk@jwilk.net>
 #
 # This file is part of pdf2djvu.
 #
@@ -14,11 +14,13 @@
 # General Public License for more details.
 
 import os
+import re
+import xml.etree.cElementTree as etree
 
 from tools import (
     assert_equal,
+    assert_true,
     case,
-    re,
 )
 
 here = os.path.dirname(__file__)
@@ -32,10 +34,19 @@ class test(case):
             line = file.readline()
         self.changelog_version = line.split()[1].strip('()')
 
+    def test_manpage(self):
+        path = os.path.join(srcdir, 'doc', 'manpage.xml')
+        for event, elem in etree.iterparse(path):
+            if elem.tag == 'refmiscinfo' and elem.get('class') == 'version':
+                assert_equal(elem.text, self.changelog_version)
+                break
+        else:
+            assert_true(False, msg="missing <refmiscinfo class='version'>")
+
     def test_executable(self):
         r = self.pdf2djvu('--version')
-        r.assert_(stderr=re('^pdf2djvu [0-9.]+$', re.M), rc=0)
-        exec_version = r.stderr.splitlines()[0]
+        r.assert_(stdout=re.compile('^pdf2djvu [0-9.]+$', re.M), rc=0)
+        exec_version = r.stdout.splitlines()[0]
         _, exec_version = exec_version.split()
         assert_equal(exec_version, self.changelog_version)
 
