@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2009-2016 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2009-2017 Jakub Wilk <jwilk@jwilk.net>
 #
 # This file is part of pdf2djvu.
 #
@@ -15,33 +15,32 @@
 
 from __future__ import print_function
 
-import collections
 import codecs
+import collections
 import inspect
 import itertools
 import locale
 import os
 import pipes
 import re
+import signal
 import subprocess as ipc
 import sys
 
-re.compile.escape = re.escape
-re.compile.M = re.M
-re.compile.DOTALL = re.DOTALL
-re = re.compile
-re.type = type(re(''))
-
 import nose
-
 from nose import SkipTest
-
 from nose.tools import (
     assert_equal,
     assert_not_equal,
     assert_true,
 )
 
+b''  # Python >= 2.6 is required
+if sys.version_info >= (3, 0):
+    raise RuntimeError('Python 2.X is required')
+
+re_type = type(re.compile(''))
+
 def noseimport(vmaj, vmin, name=None):
     def wrapper(f):
         if sys.version_info >= (vmaj, vmin):
@@ -94,11 +93,40 @@ if sys.version_info >= (2, 7):
 @noseimport(2, 7, 'assert_regexp_matches')
 def assert_regex(text, regex):
     if isinstance(regex, basestring):
-        regex = re(regex)
+        regex = re.compile(regex)
     if not regex.search(text):
         message = "Regex didn't match: {0!r} not found in {1!r}".format(regex.pattern, text)
         assert_true(False, msg=message)
 
+def _get_signal_names():
+    signame_pattern = re.compile('^SIG[A-Z0-9]*$')
+    data = dict(
+        (name, getattr(signal, name))
+        for name in dir(signal)
+        if signame_pattern.match(name)
+    )
+    try:
+        if data['SIGABRT'] == data['SIGIOT']:
+            del data['SIGIOT']
+    except KeyError:
+        pass
+    try:
+        if data['SIGCHLD'] == data['SIGCLD']:
+            del data['SIGCLD']
+    except KeyError:
+        pass
+    return dict((no, name) for name, no in data.iteritems())
+
+class _ipc_rc(int):
+
+    _signal_names = _get_signal_names()
+
+    def __repr__(self):
+        try:
+            return '-' + self._signal_names[-self]
+        except KeyError:
+            return str(self)
+
 class ipc_result(object):
 
     def __init__(self, stdout, stderr, rc):
@@ -109,15 +137,15 @@ class ipc_result(object):
     def assert_(self, stdout='', stderr='', rc=0):
         if stderr is None:
             pass
-        elif isinstance(stderr, re.type):
+        elif isinstance(stderr, re_type):
             assert_regex(self.stderr, stderr)
         else:
             assert_multi_line_equal(self.stderr, stderr)
         if rc is not None:
-            assert_equal(self.rc, rc)
+            assert_equal(_ipc_rc(self.rc), _ipc_rc(rc))
         if stdout is None:
             pass
-        elif isinstance(stdout, re.type):
+        elif isinstance(stdout, re_type):
             assert_regex(self.stdout, stdout)
         else:
             assert_multi_line_equal(self.stdout, stdout)
@@ -135,7 +163,10 @@ def _get_locale_for_encoding(encoding):
                 locale.setlocale(locale.LC_ALL, new_locale)
             except locale.Error:
                 continue
-            return new_locale
+            locale_encoding = locale.getpreferredencoding(False)
+            locale_encoding = codecs.lookup(locale_encoding).name
+            if encoding == locale_encoding:
+                return new_locale
     finally:
         locale.setlocale(locale.LC_ALL, old_locale)
     raise SkipTest(
@@ -149,7 +180,7 @@ class case(object):
     _poppler_version = None
 
     def get_pdf2djvu_command(self):
-        if re(r'\A[[a-zA-Z0-9_+/=.,:%-]+\Z').match(self._pdf2djvu_command):
+        if re.compile(r'\A[[a-zA-Z0-9_+/=.,:%-]+\Z').match(self._pdf2djvu_command):
             return (self._pdf2djvu_command,)
         return ('sh', '-c', self._pdf2djvu_command + ' "$@"', 'sh')
 
@@ -199,8 +230,8 @@ class case(object):
         if os.getenv('pdf2djvu_win32'):
             result.stderr = result.stderr.replace('\r\n', '\n')
         if sys.platform.startswith('openbsd'):
-            # FIXME: https://bitbucket.org/jwilk/pdf2djvu/issues/108
-            result.stderr = re(
+            # FIXME: https://github.com/jwilk/pdf2djvu/issues/108
+            result.stderr = re.compile(
                 r'Magick: Failed to close module [(]"\w*: Invalid handle\"[)].\n'
             ).sub('', result.stderr)
         return result
@@ -265,9 +296,9 @@ class case(object):
     def require_poppler(self, *version):
         if self._poppler_version is None:
             r = self.pdf2djvu('--version')
-            r.assert_(stderr=re('^pdf2djvu '), rc=0)
-            print(repr(r.stderr))
-            match = re('^[+] Poppler ([0-9.]+)$', re.M).search(r.stderr)
+            r.assert_(stderr=re.compile('^pdf2djvu '), rc=0)
+            print(r.stderr)
+            match = re.compile('^[+] Poppler ([0-9.]+)$', re.M).search(r.stderr)
             self._poppler_version = tuple(int(x) for x in match.group(1).split('.'))
         if self._poppler_version < version:
             str_version = '.'.join(str(v) for v in version)
@@ -281,8 +312,8 @@ class case(object):
                 feature_enabled = not os.getenv('pdf2djvu_win32')
             else:
                 r = self.pdf2djvu('--version')
-                r.assert_(stderr=re('^pdf2djvu '), rc=0)
-                feature_enabled = feature in r.stderr
+                r.assert_(stdout=re.compile('^pdf2djvu '), rc=0)
+                feature_enabled = feature in r.stdout
             self._feature_cache[feature] = feature_enabled
         if not feature_enabled:
             raise SkipTest(feature + ' support missing')
@@ -306,11 +337,11 @@ def checkboard(width, height):
     pixels = image.load()
     for x in xrange(width):
         for y in xrange(height):
-            color = 0xff * ((x ^ y) & 1)
+            color = 0xFF * ((x ^ y) & 1)
             pixels[x, y] = color
     return image
 
-_ppm_re = re(r'P6\s+\d+\s+\d+\s+255\s(.*)\Z', re.DOTALL)
+_ppm_re = re.compile(r'P6\s+\d+\s+\d+\s+255\s(.*)\Z', re.DOTALL)
 def count_ppm_colors(b):
     match = _ppm_re.match(b)
     assert_is_not_none(match)
